@@ -5,6 +5,5 @@
 
 __author__ = """Alec Thomson"""
 __email__ = 'alec.thomson@csiro.au'
-__version__ = '0.0.2'
 
-from dafits.read import da_from_fits, da_from_fitsio
\ No newline at end of file
+from dafits.core import read, write
\ No newline at end of file
